@@ -78,7 +78,10 @@ fn generate_router_rtp_capabilities_succeeds() {
                 preferred_payload_type: 102, // 102 is the third available dynamic PT.
                 clock_rate: NonZeroU32::new(90000).unwrap(),
                 parameters: RtpCodecParametersParameters::from([
-                    ("packetization-mode", 0_u32.into()),
+                    // Since packetization-mode param was not included in the
+                    // H264 codec and it's default value is 0, it's not added
+                    // by ortc file.
+                    // ("packetization-mode", 0_u32.into()),
                     ("level-asymmetry-allowed", 1_u32.into()),
                     ("profile-level-id", "42e01f".into()),
                     ("foo", "bar".into()),
@@ -115,17 +118,6 @@ fn generate_router_rtp_capabilities_unsupported() {
         }]),
         Err(RtpCapabilitiesError::UnsupportedCodec { .. })
     ));
-
-    assert!(matches!(
-        generate_router_rtp_capabilities(vec![RtpCodecCapability::Video {
-            mime_type: MimeTypeVideo::H264,
-            preferred_payload_type: None,
-            clock_rate: NonZeroU32::new(90000).unwrap(),
-            parameters: RtpCodecParametersParameters::from([("packetization-mode", 5u32.into())]),
-            rtcp_feedback: vec![],
-        }]),
-        Err(RtpCapabilitiesError::UnsupportedCodec { .. })
-    ));
 }
 
 #[test]
@@ -221,20 +213,20 @@ fn get_producer_rtp_parameters_mapping_get_consumable_rtp_parameters_get_consume
             RtpEncodingParameters {
                 ssrc: Some(11111111),
                 rtx: Some(RtpEncodingParametersRtx { ssrc: 11111112 }),
-                scalability_mode: Some("L1T3".to_string()),
+                scalability_mode: ScalabilityMode::L1T3,
                 max_bitrate: Some(111111),
                 ..RtpEncodingParameters::default()
             },
             RtpEncodingParameters {
                 ssrc: Some(21111111),
                 rtx: Some(RtpEncodingParametersRtx { ssrc: 21111112 }),
-                scalability_mode: Some("L1T3".to_string()),
+                scalability_mode: ScalabilityMode::L1T3,
                 max_bitrate: Some(222222),
                 ..RtpEncodingParameters::default()
             },
             RtpEncodingParameters {
                 rid: Some("high".to_string()),
-                scalability_mode: Some("L1T3".to_string()),
+                scalability_mode: ScalabilityMode::L1T3,
                 max_bitrate: Some(333333),
                 ..RtpEncodingParameters::default()
             },
@@ -328,7 +320,7 @@ fn get_producer_rtp_parameters_mapping_get_consumable_rtp_parameters_get_consume
             .get(0)
             .unwrap()
             .scalability_mode,
-        Some("L1T3".to_string()),
+        ScalabilityMode::L1T3,
     );
     assert_eq!(
         consumable_rtp_parameters.encodings.get(1).unwrap().ssrc,
@@ -348,7 +340,7 @@ fn get_producer_rtp_parameters_mapping_get_consumable_rtp_parameters_get_consume
             .get(1)
             .unwrap()
             .scalability_mode,
-        Some("L1T3".to_string()),
+        ScalabilityMode::L1T3,
     );
     assert_eq!(
         consumable_rtp_parameters.encodings.get(2).unwrap().ssrc,
@@ -368,7 +360,7 @@ fn get_producer_rtp_parameters_mapping_get_consumable_rtp_parameters_get_consume
             .get(2)
             .unwrap()
             .scalability_mode,
-        Some("L1T3".to_string()),
+        ScalabilityMode::L1T3,
     );
 
     assert_eq!(
@@ -415,49 +407,48 @@ fn get_producer_rtp_parameters_mapping_get_consumable_rtp_parameters_get_consume
         ],
         header_extensions: vec![
             RtpHeaderExtension {
-                kind: Some(MediaKind::Audio),
+                kind: MediaKind::Audio,
                 uri: RtpHeaderExtensionUri::Mid,
                 preferred_id: 1,
                 preferred_encrypt: false,
                 direction: RtpHeaderExtensionDirection::SendRecv,
             },
             RtpHeaderExtension {
-                kind: Some(MediaKind::Video),
+                kind: MediaKind::Video,
                 uri: RtpHeaderExtensionUri::Mid,
                 preferred_id: 1,
                 preferred_encrypt: false,
                 direction: RtpHeaderExtensionDirection::SendRecv,
             },
             RtpHeaderExtension {
-                kind: Some(MediaKind::Video),
+                kind: MediaKind::Video,
                 uri: RtpHeaderExtensionUri::RtpStreamId,
                 preferred_id: 2,
                 preferred_encrypt: false,
                 direction: RtpHeaderExtensionDirection::SendRecv,
             },
             RtpHeaderExtension {
-                kind: Some(MediaKind::Audio),
+                kind: MediaKind::Audio,
                 uri: RtpHeaderExtensionUri::AudioLevel,
                 preferred_id: 8,
                 preferred_encrypt: false,
                 direction: RtpHeaderExtensionDirection::SendRecv,
             },
             RtpHeaderExtension {
-                kind: Some(MediaKind::Video),
+                kind: MediaKind::Video,
                 uri: RtpHeaderExtensionUri::VideoOrientation,
                 preferred_id: 11,
                 preferred_encrypt: false,
                 direction: RtpHeaderExtensionDirection::SendRecv,
             },
             RtpHeaderExtension {
-                kind: Some(MediaKind::Video),
+                kind: MediaKind::Video,
                 uri: RtpHeaderExtensionUri::TimeOffset,
                 preferred_id: 12,
                 preferred_encrypt: false,
                 direction: RtpHeaderExtensionDirection::SendRecv,
             },
         ],
-        fec_mechanisms: vec![],
     };
 
     let consumer_rtp_parameters =
@@ -511,7 +502,7 @@ fn get_producer_rtp_parameters_mapping_get_consumable_rtp_parameters_get_consume
             .get(0)
             .unwrap()
             .scalability_mode,
-        Some("S3T3".to_string()),
+        ScalabilityMode::S3T3,
     );
     assert_eq!(
         consumer_rtp_parameters
@@ -595,7 +586,7 @@ fn get_producer_rtp_parameters_mapping_get_consumable_rtp_parameters_get_consume
             .get(0)
             .unwrap()
             .scalability_mode,
-        Some("L1T3".to_string()),
+        ScalabilityMode::L1T3,
     );
     assert!(pipe_consumer_rtp_parameters
         .encodings
@@ -621,7 +612,7 @@ fn get_producer_rtp_parameters_mapping_get_consumable_rtp_parameters_get_consume
             .get(1)
             .unwrap()
             .scalability_mode,
-        Some("L1T3".to_string()),
+        ScalabilityMode::L1T3,
     );
     assert!(pipe_consumer_rtp_parameters
         .encodings
@@ -647,7 +638,7 @@ fn get_producer_rtp_parameters_mapping_get_consumable_rtp_parameters_get_consume
             .get(2)
             .unwrap()
             .scalability_mode,
-        Some("L1T3".to_string()),
+        ScalabilityMode::L1T3,
     );
 
     assert_eq!(
