@@ -217,6 +217,8 @@ impl Inner {
 
             self.handlers.close.call_simple();
 
+            let subscription_handler = self.subscription_handler.lock().take();
+
             if close_request {
                 let channel = self.channel.clone();
                 let request = TransportCloseRequest {
@@ -225,7 +227,6 @@ impl Inner {
                         transport_id: self.id,
                     },
                 };
-                let subscription_handler = self.subscription_handler.lock().take();
 
                 self.executor
                     .spawn(async move {
@@ -238,6 +239,14 @@ impl Inner {
                         drop(subscription_handler);
                     })
                     .detach();
+            } else {
+                self.executor
+                    .spawn(async move {
+                        // Drop from a different thread to avoid deadlock with recursive dropping
+                        // from within another subscription drop.
+                        drop(subscription_handler);
+                    })
+                    .detach();
             }
         }
     }
@@ -271,7 +280,7 @@ impl fmt::Debug for PipeTransport {
     }
 }
 
-#[async_trait(?Send)]
+#[async_trait]
 impl Transport for PipeTransport {
     fn id(&self) -> TransportId {
         self.inner.id
@@ -414,7 +423,7 @@ impl Transport for PipeTransport {
     }
 }
 
-#[async_trait(?Send)]
+#[async_trait]
 impl TransportGeneric for PipeTransport {
     type Dump = PipeTransportDump;
     type Stat = PipeTransportStat;
