@@ -254,6 +254,8 @@ impl Inner {
 
             self.handlers.close.call_simple();
 
+            let subscription_handler = self.subscription_handler.lock().take();
+
             if close_request {
                 let channel = self.channel.clone();
                 let request = TransportCloseRequest {
@@ -262,7 +264,6 @@ impl Inner {
                         transport_id: self.id,
                     },
                 };
-                let subscription_handler = self.subscription_handler.lock().take();
 
                 self.executor
                     .spawn(async move {
@@ -275,6 +276,14 @@ impl Inner {
                         drop(subscription_handler);
                     })
                     .detach();
+            } else {
+                self.executor
+                    .spawn(async move {
+                        // Drop from a different thread to avoid deadlock with recursive dropping
+                        // from within another subscription drop.
+                        drop(subscription_handler);
+                    })
+                    .detach();
             }
         }
     }
@@ -301,7 +310,7 @@ impl fmt::Debug for PlainTransport {
     }
 }
 
-#[async_trait(?Send)]
+#[async_trait]
 impl Transport for PlainTransport {
     fn id(&self) -> TransportId {
         self.inner.id
@@ -444,7 +453,7 @@ impl Transport for PlainTransport {
     }
 }
 
-#[async_trait(?Send)]
+#[async_trait]
 impl TransportGeneric for PlainTransport {
     type Dump = PlainTransportDump;
     type Stat = PlainTransportStat;
