@@ -149,7 +149,7 @@ pub(super) enum TransportType {
 /// * [`DirectTransport`](crate::direct_transport::DirectTransport)
 ///
 /// For additional methods see [`TransportGeneric`].
-#[async_trait(?Send)]
+#[async_trait]
 pub trait Transport: Debug + Send + Sync + private::CloneTransport {
     /// Transport id.
     #[must_use]
@@ -282,7 +282,7 @@ impl Clone for Box<dyn Transport> {
 }
 
 /// Generic transport trait with methods available on all transports in addition to [`Transport`].
-#[async_trait(?Send)]
+#[async_trait]
 pub trait TransportGeneric: Transport + Clone + 'static {
     /// Dump data structure specific to each transport.
     #[doc(hidden)]
@@ -360,7 +360,7 @@ pub enum ConsumeDataError {
     Request(RequestError),
 }
 
-#[async_trait(?Send)]
+#[async_trait]
 pub(super) trait TransportImpl: TransportGeneric {
     fn router(&self) -> &Router;
 
