@@ -301,6 +301,8 @@ impl Inner {
 
             self.handlers.close.call_simple();
 
+            let subscription_handler = self.subscription_handler.lock().take();
+
             if close_request {
                 let channel = self.channel.clone();
                 let request = TransportCloseRequest {
@@ -309,7 +311,6 @@ impl Inner {
                         transport_id: self.id,
                     },
                 };
-                let subscription_handler = self.subscription_handler.lock().take();
 
                 self.executor
                     .spawn(async move {
@@ -322,6 +323,14 @@ impl Inner {
                         drop(subscription_handler);
                     })
                     .detach();
+            } else {
+                self.executor
+                    .spawn(async move {
+                        // Drop from a different thread to avoid deadlock with recursive dropping
+                        // from within another subscription drop.
+                        drop(subscription_handler);
+                    })
+                    .detach();
             }
         }
     }
@@ -356,7 +365,7 @@ impl fmt::Debug for WebRtcTransport {
     }
 }
 
-#[async_trait(?Send)]
+#[async_trait]
 impl Transport for WebRtcTransport {
     fn id(&self) -> TransportId {
         self.inner.id
@@ -499,7 +508,7 @@ impl Transport for WebRtcTransport {
     }
 }
 
-#[async_trait(?Send)]
+#[async_trait]
 impl TransportGeneric for WebRtcTransport {
     type Dump = WebRtcTransportDump;
     type Stat = WebRtcTransportStat;
